#!/bin/sh
### BEGIN INIT INFO
# Provides:
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start jar at boot time
# Description:       Enable service provided by jar.
### END INIT INFO
service_name=<%= @name %>
service_user=<%= @user %>
path_to_jar=<%= @deploy_directory %>/$service_name.jar
pid_file=/tmp/$service_name
log=<%= @log_directory %>/$service_name.log
jar_args="<%= @jar_args %>"

get_pid() {
    cat "$pid_file"
}

is_running() {
    [ -f "$pid_file" ] && ps `get_pid` > /dev/null 2>&1
}

case "$1" in
    start)
    if is_running; then
        echo "Already started"
    else
        echo "Starting $name"
        su $service_user -c "nohup java -jar $path_to_jar $jar_args >> \"$log\" 2>&1 &"
        ps aux | grep $SERVICE_NAME.jar | head -n 1 | awk '{print $2}' > "$pid_file"
        echo "$SERVICE_NAME started ..."
        if ! is_running; then
            echo "Unable to start, see $stdout_log and $stderr_log"
            exit 1
        fi
    fi
    ;;
    stop)
    if is_running; then
        echo -n "Stopping $name.."
        kill `get_pid`
        for i in {1..10}
        do
            if ! is_running; then
                break
            fi

            echo -n "."
            sleep 1
        done
        echo

        if is_running; then
            echo "Not stopped; may still be shutting down or shutdown may have failed"
            exit 1
        else
            echo "Stopped"
            if [ -f "$pid_file" ]; then
                rm "$pid_file"
            fi
        fi
    else
        echo "Not running"
    fi
    ;;
    restart)
    $0 stop
    if is_running; then
        echo "Unable to stop, will not attempt to start"
        exit 1
    fi
    $0 start
    ;;
    status)
    if is_running; then
        echo "Running"
    else
        echo "Stopped"
        exit 1
    fi
    ;;
    *)
    echo "Usage: $0 {start|stop|restart|status}"
    exit 1
    ;;
esac

exit 0